@@ -8,7 +8,7 @@ class XmlElement:
         Keyword arguments:
         n -- XML tag name
         a -- Dictionary of XML attributes (default {})
-        c -- Array of children for the XML element (default [])
+        s -- Array of sublements for the XML element (default [])
         t -- Text content of the XML element
         """
         self.name = n
